@@ -136,6 +136,7 @@ objectExtend(CommandHandlerFactory.prototype, {
         // is true when the value returned by the accessor matches the specified value.
         return function(target, value) {
             var accessorResult = accessBlock(target);
+            accessorResult = selArrayToString(accessorResult);
             if (PatternMatcher.matches(value, accessorResult)) {
                 return new PredicateResult(true, "Actual value '" + accessorResult + "' did match '" + value + "'");
             } else {
@@ -150,6 +151,7 @@ objectExtend(CommandHandlerFactory.prototype, {
         // is true when the value returned by the accessor matches the specified value.
         return function(value) {
             var accessorResult = accessBlock();
+            accessorResult = selArrayToString(accessorResult);
             if (PatternMatcher.matches(value, accessorResult)) {
                 return new PredicateResult(true, "Actual value '" + accessorResult + "' did match '" + value + "'");
             } else {
@@ -304,12 +306,14 @@ ActionHandler.prototype.execute = function(seleniumApi, command) {
         // todo: this conditional logic is ugly
         seleniumApi.ensureNoUnhandledPopups();
     }
-    var terminationCondition = this.actionBlock(command.target, command.value);
-    // If the handler didn't return a wait flag, check to see if the
-    // handler was registered with the wait flag.
-    if (terminationCondition == undefined && this.wait) {
-        terminationCondition = seleniumApi.makePageLoadCondition();
-    }
+    
+    var handlerCondition = this.actionBlock(command.target, command.value);
+    
+    // page load waiting takes precedence over any wait condition returned by
+    // the action handler.
+    var terminationCondition = (this.wait)
+        ? seleniumApi.makePageLoadCondition() : handlerCondition;
+    
     return new ActionResult(terminationCondition);
 };
 
@@ -328,7 +332,14 @@ AccessorHandler.prototype.execute = function(seleniumApi, command) {
 };
 
 function AccessorResult(result) {
+  if (result.terminationCondition) {
+    var self = this;
+    this.terminationCondition = function() {
+      return result.terminationCondition.call(self);
+    };
+  } else {
     this.result = result;
+  }
 }
 
 /**
@@ -360,14 +371,15 @@ AssertHandler.prototype.execute = function(seleniumApi, command) {
 function AssertResult() {
     this.passed = true;
 }
+
 AssertResult.prototype.setFailed = function(message) {
     this.passed = null;
     this.failed = true;
     this.failureMessage = message;
-}
+};
 
 function SeleniumCommand(command, target, value, isBreakpoint) {
-    this.command = command;
+    this.command = command.trim();
     this.target = target;
     this.value = value;
     this.isBreakpoint = isBreakpoint;
